==> gosa_2.1.1.orig.tar.gz: gosa-2.1.1/html/getldif.php <==
<?php
/*
  This code is part of GOsa (https://gosa.gonicus.de)
  Copyright (C) 2003  Cajus Pollmeier

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

  function dump_ldap ($mode= 0)
  {
    global $config;

    $server= preg_replace("/^[^\/]+\/\//", "", $config->current['SERVER']);
    $server= preg_replace("/:.*$/", "", $server);
    $port= preg_replace("/^ldap:[^:]+[:]?/", "", $config->current['SERVER']);
    $port= ($port=="")?"389":$port;
    
    if ($mode == 0){
      $query= "ldapsearch -x -LLL -D \"".$config->current['ADMIN'].
              "\" -w \"".$config->current['PASSWORD'].
              "\" -h $server".
              " -p $port".
              " -b \"".$config->current['BASE']."\" 'objectClass=*'";
      $res= `$query`;
      echo $res;
    } else {
      $query= "ldapsearch -x -LLL -D \"".$config->current['ADMIN'].
              "\" -w \"".$config->current['PASSWORD'].
              "\" -h $server".
              " -p $port".
              " -b \"".$config->current['BASE']."\" 'objectClass=ivbbEntry' gouvernmentOrganizationalUnit houseIdentifier vocation ivbbLastDeliveryCollective gouvernmentOrganizationalPersonLocality gouvernmentOrganizationalUnitDescription gouvernmentOrganizationalUnitSubjectArea functionalTitle role certificateSerialNumber userCertificate publicVisible telephoneNumber seeAlso description title x121Address registeredAddress destinationIndicator preferredDeliveryMethod telexNumber teletexTerminalIdentifier telephoneNumber internationaliSDNNumber facsimileTelephoneNumber street postOfficeBox postalCode postalAddress physicalDeliveryOfficeName ou st l audio businessCategory carLicense departmentNumber displayName employeeNumber employeeType givenName homePhone homePostalAddress initials jpegPhoto labeledURI mail manager mobile o pager photo roomNumber secretary userCertificate x500uniqueIdentifier preferredLanguage userSMIMECertificate userPKCS12";
      $res= `$query`;
      echo preg_replace('/'.get_people_ou().',/i', "", $res);
    }
  }


  /* Basic setup, remove eventually registered sessions */
  @require_once ("../include/php_setup.inc");
  @require_once ("functions.inc");
  error_reporting (E_ALL);
  session_start ();
 
  /* Logged in? Simple security check */
  if (!isset($_SESSION['ui'])){
    gosa_log ("Error: getpic.php called without session");
    header ("Location: ../index.php");
    exit;
  }
  $ui= $_SESSION["ui"];
  $config= $_SESSION['config'];
  
  header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
  header("Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT");
  header("Cache-Control: no-cache");
  header("Pragma: no-cache");
  header("Cache-Control: post-check=0, pre-check=0");

  header("Content-type: text/plain");

  /* Check ACL's */
  $acl= get_permissions ($config->current['BASE'], $ui->subtreeACL);
  $acl= get_module_permission($acl, "all", $config->current['BASE']);
  if (chkacl($acl, "all") != ""){
	header ("Location: ../index.php");
	exit;
  }

  switch ($_GET['ivbb']){
    case 0:	dump_ldap (0);
		break;

    case 1:	dump_ldap (1);
		break;

    default:
		echo "Error in ivbb parameter. Request aborted.";
  }
?>

==> gosa_2.3.orig.tar.gz: gosa-2.3.orig/html/getldif.php <==
<?php
/*
  This code is part of GOsa (https://gosa.gonicus.de)
  Copyright (C) 2003  Cajus Pollmeier

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

  function dump_ldap ($mode= 0)
  {
    global $config;

    $server= preg_replace("/^[^\/]+\/\//", "", $config->current['SERVER']);
    $server= preg_replace("/:.*$/", "", $server);
    $port= preg_replace("/^ldap:[^:]+[:]?/", "", $config->current['SERVER']);
    $port= ($port=="")?"389":$port;
    
    if ($mode == 0){
      $query= "ldapsearch -x -LLL -D \"".$config->current['ADMIN'].
              "\" -w \"".$config->current['PASSWORD'].
              "\" -h $server".
              " -p $port".
              " -b \"".$config->current['BASE']."\" 'objectClass=*'";
      $res= `$query`;
      echo $res;
    } else {
      $query= "ldapsearch -x -LLL -D \"".$config->current['ADMIN'].
              "\" -w \"".$config->current['PASSWORD'].
              "\" -h $server".
              " -p $port".
              " -b \"".$config->current['BASE']."\" 'objectClass=ivbbEntry' gouvernmentOrganizationalUnit houseIdentifier vocation ivbbLastDeliveryCollective gouvernmentOrganizationalPersonLocality gouvernmentOrganizationalUnitDescription gouvernmentOrganizationalUnitSubjectArea functionalTitle role certificateSerialNumber userCertificate publicVisible telephoneNumber seeAlso description title x121Address registeredAddress destinationIndicator preferredDeliveryMethod telexNumber teletexTerminalIdentifier telephoneNumber internationaliSDNNumber facsimileTelephoneNumber street postOfficeBox postalCode postalAddress physicalDeliveryOfficeName ou st l audio businessCategory carLicense departmentNumber displayName employeeNumber employeeType givenName homePhone homePostalAddress initials jpegPhoto labeledURI mail manager mobile o pager photo roomNumber secretary userCertificate x500uniqueIdentifier preferredLanguage userSMIMECertificate userPKCS12";
      $res= `$query`;
      if (get_people_ou() != ""){
	      echo preg_replace('/'.get_people_ou().'/i', "", $res);
      } else {
	      echo $res;
      }
    }
  }


  /* Basic setup, remove eventually registered sessions */
  @require_once ("../include/php_setup.inc");
  @require_once ("functions.inc");
  error_reporting (E_ALL);
  session_start ();
 
  /* Logged in? Simple security check */
  if (!isset($_SESSION['ui'])){
    gosa_log ("Error: getpic.php called without session");
    header ("Location: ../index.php");
    exit;
  }
  $ui= $_SESSION["ui"];
  $config= $_SESSION['config'];
  
  header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
  header("Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT");
  header("Cache-Control: no-cache");
  header("Pragma: no-cache");
  header("Cache-Control: post-check=0, pre-check=0");

  header("Content-type: text/plain");

  /* Check ACL's */
  $acl= get_permissions ($config->current['BASE'], $ui->subtreeACL);
  $acl= get_module_permission($acl, "all", $config->current['BASE']);
  if (chkacl($acl, "all") != ""){
	header ("Location: ../index.php");
	exit;
  }

  switch ($_GET['ivbb']){
    case 0:	dump_ldap (0);
		break;

    case 1:	dump_ldap (1);
		break;

    default:
		echo "Error in ivbb parameter. Request aborted.";
  }
?>
